@@ -682,10 +682,10 @@ def ControllerMethod(
                 ###- request.full_path:           /alert/dingding/test?x=y
                 ###- request.args:                ImmutableMultiDict([('x', 'y')])
                 ###- request.args.get('x'):       y
-            responseBody = completeResponse[0] if ObjectHelper.isNotNone(completeResponse[0]) else {'message' : completeResponse[-1].enumName}
-            status = completeResponse[1]
+            status = completeResponse[-1]
+            responseBody = completeResponse[0] if ObjectHelper.isNotNone(completeResponse[0]) else {'message' : status.enumName}
             additionalResponseHeaders = completeResponse[2]
-            httpResponse = FlaskUtil.buildHttpResponse(responseBody, produces, HttpStatus.map(status).enumValue, additionalResponseHeaders)
+            httpResponse = FlaskUtil.buildHttpResponse(additionalResponseHeaders, responseBody, HttpStatus.map(status).enumValue, produces)
 
             try:
                 if logResponse :
